/*  This source file is (c) 2010 - 2012 Volker Schatz
    It is licensed under Version 3 or later of the Gnu General Public License
    (see http://www.gnu.org/licenses/gpl.html for details)              */

/*! \file

    \brief Simplified low-level API for the IRex Iliad

    This library contains wrapper functions for display updates, controlling
    the busy LED, toolbar and pagebar, and for mapping the frame buffer into
    RAM.
*/

#ifndef ILIAD_API_H
#define ILIAD_API_H

#include <liberipc/eripc.h>

#ifndef UAID
#define UAID		1
#endif

#define ILIAD_NOERR	0
#define ILIAD_ERR_CONN	1
#define ILIAD_ERR_ERLIB	2
#define ILIAD_ERR_RANGE	3

#define LED_OFF		0
#define LED_BLINK	1
#define LED_ON		2

erClientChannel_t busyd_channel();
int set_led(int state);

erClientChannel_t toolbar_channel();
int init_icons(int *iconlist);

erClientChannel_t pagebar_channel();
int init_pagebar(int npages, int page, int pagepos, int zoom);
int set_pagebar_page(int page, int pagepos);

unsigned char *framebuffer();
void unmap_framebuffer();

#define DISP_4BIT	0
#define DISP_2BIT	2
#define DISP_1BIT	1
#define DISP_IMMED	3	/*  update display immediately  */
#define DISP_01SEC	2	/*  within 0.1 seconds, according to erdm.h  */
#define DISP_05SEC	1	/*  within 0.5 sec  */
#define DISP_15SEC	0	/*  within 1.5 sec  */

void update_now4bit();
int update_display(int quality, int priority);
void clear_display();

#endif

